@@ -65,7 +65,7 @@ pub fn expand_function(
     Ok(quote! {
         #doc
         pub fn #name(&self #input) -> #result {
-            Contract::method_hash(&self.fuel_client, self.contract_id,
+            Contract::method_hash(&self.provider, self.contract_id, &self.wallet,
                 #tokenized_signature, #output_params_token, #arg).expect("method not found (this should never happen)")
         }
     })
@@ -257,8 +257,9 @@ mod tests {
 #[doc = "Calls the contract's `HelloWorld` (0x0000000097d4de45) function"]
 pub fn HelloWorld(&self, bimbam: bool) -> ContractCall<()> {
     Contract::method_hash(
-        &self.fuel_client,
+        &self.provider,
         self.contract_id,
+        &self.wallet,
         [0, 0, 0, 0, 151, 212, 222, 69],
         &[],
         &[bimbam.into_token() ,]
@@ -364,8 +365,9 @@ pub fn hello_world(
     the_only_allowed_input: SomeWeirdFrenchCuisine
 ) -> ContractCall<((bool , u64 ,) , (bool, u64 ,))> {
     Contract::method_hash(
-        &self.fuel_client,
+        &self.provider,
         self.contract_id,
+        &self.wallet,
         [0, 0, 0, 0, 118, 178, 90, 36],
         &[
             ParamType::Struct(vec![ParamType::Bool, ParamType::U64]),
